@@ -2,15 +2,18 @@
 ##' 
 ##' @name games-package
 ##' @docType package
+##' @section Acknowledgements: We thank the Wallis Institute of Political
+##' Economy for financial support.
 ##' @references
 ##' Curtis S. Signorino.  2003.  "Structure and Uncertainty
 ##' in Discrete Choice Models."  \emph{Political Analysis} 11:316--344.
 NULL
 
+##' Print a strategic model object
+##' 
 ##' The default method for printing a \code{game} object.
 ##'
 ##' Prints the call and coefficients of a fitted strategic model.
-##' @title Print a strategic model object
 ##' @param x a fitted model of class \code{game}
 ##' @param ... other arguments, currently ignored
 ##' @return \code{x}, invisibly
@@ -67,17 +70,21 @@ print.game <- function(x, ...)
         cat("\nWarning: Model fitting did not converge\nCode:",
             x$convergence$code, "\nMessage:", x$convergence$message)
     }
-    
+
+    if (!x$localID)
+        warning("Hessian is not negative definite; coefficients may not be locally identified")
+
     cat("\n")
     invisible(oldx)
 }
 
+##' Summarize a strategic model object
+##' 
 ##' The default method for summarizing a \code{game} object.
 ##'
 ##' Forms the standard regression results table from a fitted strategic model.
 ##' Normally used interactively, in conjunction with
 ##' \code{\link{print.summary.game}}.
-##' @title Summarize a strategic model object
 ##' @method summary game
 ##' @S3method summary game
 ##' @param object a fitted model of class \code{game}
@@ -111,16 +118,18 @@ summary.game <- function(object, useboot = TRUE, ...)
     ans$fixed.terms <- object$coefficients[object$fixed]
     ans$convergence <- object$convergence
     ans$useboot <- useboot
+    ans$localID <- object$localID
     class(ans) <- "summary.game"
 
     return(ans)
 }
 
+##' Print strategic model summary
+##' 
 ##' Print output from \code{summary.game}
 ##'
 ##' Prints the standard regression results table from a fitted strategic model,
 ##' along with the log-likelihood, AIC, and number of observations.
-##' @title Print strategic model summary
 ##' @method print summary.game
 ##' @S3method print summary.game
 ##' @param x an object of class \code{summary.game}, typically produced by
@@ -153,6 +162,8 @@ print.summary.game <- function(x, ...)
         cat("\nWarning: Model fitting did not converge\nCode:",
             x$convergence$code, "\nMessage:", x$convergence$message)
     }
+    if (!x$localID)
+        warning("Hessian is not negative definite; coefficients may not be locally identified")
     invisible(x)
 }
 
@@ -184,6 +195,8 @@ logLik.summary.game <- function(object, ...)
     return(ans)
 }
 
+##' Predicted probabilities for strategic models
+##' 
 ##' Makes predicted probabilities from a strategic model.
 ##'
 ##' This method uses a fitted strategic model to make predictions for a new
@@ -192,7 +205,6 @@ logLik.summary.game <- function(object, ...)
 ##' For many uses, such as analyzing the marginal effect of a particular
 ##' independent variable, the function \code{\link{predProbs}} will be more
 ##' convenient.
-##' @title Predicted probabilities for strategic models
 ##' @aliases predict.game predict.egame12 predict.egame122 predict.egame123
 ##' predict.ultimatum
 ##' @usage
